summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorAdam <Adam@anope.org>2011-12-23 12:29:30 -0500
committerAdam <Adam@anope.org>2011-12-23 12:29:30 -0500
commit1a4157b7f40f928fb1f3092cc9069f4b359f8a40 (patch)
tree106677b5440ceb82b9f7e1bd21d036bac8d0c0ba /include
parent3bcb2856909ea8637b28b526a2afd8cf8f801f88 (diff)
Add DT_ALLOW_EMPTY config flag, allow fantasychars to be empty
Diffstat (limited to 'include')
-rw-r--r--include/config.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/include/config.h b/include/config.h
index 51fcfc424..b411cb897 100644
--- a/include/config.h
+++ b/include/config.h
@@ -41,7 +41,8 @@ enum ConfigDataType
DT_TIME, // Time value
DT_NORELOAD = 32, // Item can't be reloaded after startup
DT_ALLOW_WILD = 64, // Allow wildcards/CIDR in DT_IPADDRESS
- DT_ALLOW_NEWLINE = 128 // New line characters allowed in DT_STRING
+ DT_ALLOW_NEWLINE = 128, // New line characters allowed in DT_STRING
+ DT_ALLOW_EMPTY = 256 // Allow empty value
};
/** Holds a config value, either string, integer or boolean.